@@ -11,13 +11,14 @@
 #'   Significance level/s.
 #'
 #' @family Wald Confidence Intervals Functions
-#' @keywords alpha internal
+#' @keywords wald alpha internal
 #' @noRd
-.ProbsofAlpha <- function(alpha = c(
-                            0.05,
-                            0.01,
-                            0.001
-                          )) {
+.ProbsofAlpha <- function(
+    alpha = c(
+      0.05,
+      0.01,
+      0.001
+    )) {
   lower <- 0.5 * alpha
   return(
     sort(
